@@ -1,4 +1,4 @@
 from . import services
 from .exceptions import RecaptchaException
 from .delay_config import DelayConfig, StandardDelayConfig
-from .solver import RecaptchaSolver
+from .solver import RecaptchaSolver, API
